/**
  *  \file game/format.cc
  *  \brief Formatting of Game Data
  *
  *  (c) 2001-2020 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "game/format.h"
#include "game/global.h"
#include "cpluslib/format.h"
#include "util/nls.h"

/** Format a turn number. Returns a user-readable string.
    \param turn Turn number to format */
string_t
formatTurnNumber(int turn)
{
    int now = getDisplayedTurn().getTurnNumber();
    int age = now - turn;
    if (age == 0) {
        return _("this turn");
    } else if (age == 1) {
        return _("last turn");
    } else if (age > 0) {
        return format(_("%d turns ago"), age);
    } else {
        return format(_("Turn %d"), now);
    }
}
