/**
  *  \file game/rangeset.h
  *  \brief Set of Circular Ranges
  *
  *  (c) 2001-2020 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_RANGESET_H
#define PCC_V2_GAME_RANGESET_H

#include <map>
#include "game/coord.h"
#include "game/playerset.h"

class GObjectType;

class GRangeSet {
 public:
    struct PointCompare {
        bool operator()(const GPoint& a, const GPoint& b)
            {
                return a.y != b.y
                    ? a.y < b.y
                    : a.x < b.x;
            }
    };
    typedef std::map<GPoint,int,PointCompare> PointMap_t;
    typedef PointMap_t::const_iterator Iterator_t;

    GRangeSet();
    ~GRangeSet();

    void add(GPoint pt, int r);
    void addObjectType(GObjectType& type, GPlayerSet playerLimit, bool markedOnly, int r);

    void clear();
    bool isEmpty() const;
    GPoint getMinimum() const;
    GPoint getMaximum() const;

    Iterator_t begin() const;
    Iterator_t end() const;

 private:
    PointMap_t points;
    GPoint min;
    GPoint max;
};

#endif
