/**
  *  \file tools/c2dumpextra.cc
  *
  *  (c) 2001-2020 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include <cstring>
#include "tools/c2dump.h"
#include "cpluslib/format.h"
#include "cpluslib/buffer.h"
#include "io/streams.h"

void
parseTeams(Stream& s, DumpOutputReceiver& r)
{
    // Read file into memory
    Buffer<char> buf;
    s.readBuffer(buf);
    DumpBlockInput bi(buf.ptr(), buf.getSize());

    // Magic
    char magic[8];
    if (bi.peek(magic, 8) != 8 || std::memcmp(magic, "CCteam0\032", 8) != 0) {
        dumpRemainder(bi, r);
    } else {
        bi.skip(8);
        r.startRecord("PCC_Teams");
        r.addField("Flags", bi.readWord());
        for (int i = 1; i <= 12; ++i)
            r.addField(format("Team(%d)", i), bi.readByte());
        for (int i = 1; i <= 12; ++i)
            r.addField(format("Color(%d)", i), bi.readByte());
        for (int i = 1; i <= 12; ++i)
            r.addField(format("Name(%d)", i), bi.readPascalString());

        // Optional part
        if (bi.getRemainingSize() > 0) {
            for (int i = 1; i <= 11; ++i)
                r.addField(format("Send_config(%d)", i), bi.readByte());
            for (int i = 1; i <= 11; ++i)
                r.addField(format("Receive_config(%d)", i), bi.readByte());
            r.addField("Passcode", bi.readWord());
        }
        r.endRecord();
        dumpRemainder(bi, r);
    }
}
